# utils
various util modules shared amongst several projects in our organization


## quickstart

```
$ echo "suggested you are using virutalenvwrapper setup at (http://virtualenvwrapper.readthedocs.io/en/latest/install.html)"
$ mkvirtualenv myproj --python=`which python3`
$ git clone https://hms-dbmi/pystarter
$ cd pystarter
$ rm -rf .git
$ pip install -r requirments-dev.txt
$ echo "basic environment setup, your good to go"
$ echo "git remote add origin https://github.com/hms-dbmi/<your_repo_name>.git"
$ echo "git push -u origin master"
```

